@@ -1,4 +1,4 @@
-/* 
+/*
  * This is the header file for the module that implements shared variables.
  * for protected multithreaded access.
  *
@@ -77,29 +77,29 @@
 #define SV_ERROR          -1   /* Object may be in incosistent state */
 
 /*
- * Definitions of functions implementing simple key/value 
+ * Definitions of functions implementing simple key/value
  * persistent storage for shared variable arrays.
  */
 
 typedef ClientData (ps_open_proc)(const char*);
 
-typedef int (ps_get_proc)   (ClientData, const char*, char**, int*);
-typedef int (ps_put_proc)   (ClientData, const char*, char*, int);
-typedef int (ps_first_proc) (ClientData, char**, char**, int*);
-typedef int (ps_next_proc)  (ClientData, char**, char**, int*);
+typedef int (ps_get_proc)   (ClientData, const char*, char**, size_t*);
+typedef int (ps_put_proc)   (ClientData, const char*, char*, size_t);
+typedef int (ps_first_proc) (ClientData, char**, char**, size_t*);
+typedef int (ps_next_proc)  (ClientData, char**, char**, size_t*);
 typedef int (ps_delete_proc)(ClientData, const char*);
 typedef int (ps_close_proc) (ClientData);
-typedef void(ps_free_proc)  (char*);
+typedef void(ps_free_proc)  (void*);
 
-typedef char* (ps_geterr_proc)(ClientData);
+typedef const char* (ps_geterr_proc)(ClientData);
 
 /*
  * This structure maintains a bunch of pointers to functions implementing
- * the simple persistence layer for the shared variable arrays. 
+ * the simple persistence layer for the shared variable arrays.
  */
 
 typedef struct PsStore {
-    char *type;                /* Type identifier of the persistent storage */
+    const char *type;          /* Type identifier of the persistent storage */
     ClientData psHandle;       /* Handle to the opened storage */
     ps_open_proc   *psOpen;    /* Function to open the persistent key store */
     ps_get_proc    *psGet;     /* Function to retrieve value bound to key */
@@ -115,7 +115,7 @@ typedef struct PsStore {
 
 /*
  * The following structure defines a collection of arrays.
- * Only the arrays within a given bucket share a lock, 
+ * Only the arrays within a given bucket share a lock,
  * allowing for more concurency.
  */
 
@@ -152,6 +152,7 @@ typedef struct Container {
     int epoch;                 /* Track object changes */
     char *chunkAddr;           /* Address of one chunk of object containers */
     struct Container *nextPtr; /* Next object container in the free list */
+    int aolSpecial;
 } Container;
 
 /*
@@ -165,6 +166,7 @@ typedef struct SvCmdInfo {
     Tcl_ObjCmdProc *objProcPtr; /* The object-based command procedure */
     Tcl_CmdDeleteProc *delProcPtr; /* Pointer to command delete function */
     struct SvCmdInfo *nextPtr;  /* Next in chain of registered commands */
+    int aolSpecial;
 } SvCmdInfo;
 
 /*
@@ -189,13 +191,13 @@ typedef struct RegType {
  */
 
 MODULE_SCOPE void
-Sv_RegisterCommand(const char*,Tcl_ObjCmdProc*,Tcl_CmdDeleteProc*);
+Sv_RegisterCommand(const char*,Tcl_ObjCmdProc*,Tcl_CmdDeleteProc*, int);
 
 MODULE_SCOPE void
 Sv_RegisterObjType(const Tcl_ObjType*, Tcl_DupInternalRepProc*);
 
 MODULE_SCOPE void
-Sv_RegisterPsStore(PsStore*);
+Sv_RegisterPsStore(const PsStore*);
 
 MODULE_SCOPE int
 Sv_GetContainer(Tcl_Interp*,int,Tcl_Obj*const objv[],Container**,int*,int);
